@@ -1,8 +1,12 @@
 """
     分布式 spider
 """
+import importlib
 import json
 import time
+import palp
+import requests
+from loguru import logger
 from palp import settings
 from threading import Thread
 from abc import abstractmethod
@@ -10,6 +14,7 @@ from quickdb import RedisLockNoWait
 from palp.buffer.buffer_item import ItemBuffer
 from palp.spider.spider_base import BaseSpider
 from palp.tool.client_heart import ClientHeart
+from requests.cookies import RequestsCookieJar
 
 
 class DistributiveSpider(BaseSpider, Thread):
@@ -91,6 +96,66 @@ class DistributiveSpider(BaseSpider, Thread):
             if master_detail and time.time() - json.loads(master_detail.decode())['time'] > 5:
                 redis_conn.delete(settings.REDIS_KEY_MASTER)
 
+    def distribute_failed_task_request(self):
+        """
+        执行失败的请求任务
+
+        :return:
+        """
+        from palp.conn import redis_conn
+
+        if settings.REQUEST_RETRY_FAILED and redis_conn.exists(settings.REDIS_KEY_QUEUE_BAD_REQUEST):
+            while True:
+                request = redis_conn.spop(settings.REDIS_KEY_QUEUE_BAD_REQUEST, count=1)
+                if not request:
+                    break
+
+                request = json.loads(request[0].decode())
+
+                # 起始函数无 callback 默认添加
+                if request['callback'] is None:
+                    request['callback'] = 'parse'
+                elif isinstance(request['callback'], str) and hasattr(self, request['callback']):
+                    pass
+                else:
+                    logger.warning(f"callback 不是 {self.name} 含有的函数：{request}")
+                    continue
+
+                request = palp.Request(**request)
+
+                # 为每一个起始函数添加一个 session、cookie_jar
+                request.session = requests.session()
+                request.cookie_jar = RequestsCookieJar()
+
+                self._queue.put(request)
+
+    def distribute_failed_task_item(self) -> None:
+        """
+        处理失败的 item
+
+        :return:
+        """
+        from palp.conn import redis_conn
+
+        modules = {}
+        if settings.ITEM_RETRY_FAILED and redis_conn.exists(settings.REDIS_KEY_QUEUE_BAD_ITEM):
+            while True:
+                item = redis_conn.spop(settings.REDIS_KEY_QUEUE_BAD_ITEM, count=1)
+                if not item:
+                    break
+
+                item = json.loads(item[0].decode())
+
+                # 重新导入 item
+                key = item['module'] + '.' + item['init']
+                if key not in modules:
+                    cls = importlib.import_module(item['module']).__getattribute__(item['init'])  # 导入
+                    modules[key] = cls
+                else:
+                    cls = modules[key]
+
+                self._queue_item.put(cls(**item['data']))
+
     def spider_logic(self):
         """
         spider 处理逻辑
@@ -117,6 +182,10 @@ class DistributiveSpider(BaseSpider, Thread):
             self._item_buffer = ItemBuffer(spider=self, q=self._queue_item)
             self._item_buffer.start()
 
+            # 分发失败的任务
+            self.distribute_failed_task_request()
+            self.distribute_failed_task_item()
+
             # 分发任务
             self.distribute_task()
         else:
